@@ -37,7 +37,9 @@ DEFAULT_CREDENTIAL_FILE = os.path.join(DEFAULT_CONFIG_PATH, 'credential.json')
 DEFAULT_GLOBUS_CREDENTIAL_FILE = os.path.join(DEFAULT_CONFIG_PATH, 'globus-credential.json')
 DEFAULT_CONFIG_FILE = os.path.join(DEFAULT_CONFIG_PATH, 'config.json')
 DEFAULT_COOKIE_JAR_FILE = os.path.join(DEFAULT_CONFIG_PATH, 'cookies.txt')
+DEFAULT_REQUESTS_TIMEOUT = (5, 12)  # (connect, read), in seconds
 DEFAULT_SESSION_CONFIG = {
+    "timeout": DEFAULT_REQUESTS_TIMEOUT,
     "retry_connect": 2,
     "retry_read": 4,
     "retry_backoff_factor": 1.0,
@@ -148,6 +150,21 @@ def init_logging(level=logging.INFO,
         logging.basicConfig(level=level, format=log_format)
 
 
+class TimeoutHTTPAdapter(HTTPAdapter):
+    def __init__(self, *args, **kwargs):
+        self.timeout = DEFAULT_REQUESTS_TIMEOUT
+        if "timeout" in kwargs:
+            self.timeout = kwargs["timeout"]
+            del kwargs["timeout"]
+        super().__init__(*args, **kwargs)
+
+    def send(self, request, **kwargs):
+        timeout = kwargs.get("timeout")
+        if timeout is None:
+            kwargs["timeout"] = self.timeout
+        return super().send(request, **kwargs)
+
+
 def get_new_requests_session(url=None, session_config=DEFAULT_SESSION_CONFIG):
     session = requests.session()
     retries = Retry(connect=session_config['retry_connect'],
@@ -155,11 +172,12 @@ def get_new_requests_session(url=None, session_config=DEFAULT_SESSION_CONFIG):
                     backoff_factor=session_config['retry_backoff_factor'],
                     status_forcelist=session_config['retry_status_forcelist'],
                     raise_on_status=True)
+    adapter = TimeoutHTTPAdapter(timeout=session_config.get("timeout", DEFAULT_REQUESTS_TIMEOUT), max_retries=retries)
     if url:
-        session.mount(url, HTTPAdapter(max_retries=retries))
+        session.mount(url, adapter)
     else:
-        session.mount('http://', HTTPAdapter(max_retries=retries))
-        session.mount('https://', HTTPAdapter(max_retries=retries))
+        session.mount('http://', adapter)
+        session.mount('https://', adapter)
 
     return session
 
@@ -248,50 +266,6 @@ def read_credential(credential_file=DEFAULT_CREDENTIAL_FILE, create_default=Fals
     return json.loads(credential, object_pairs_hook=OrderedDict)
 
 
-def get_credential(host,
-                   credential_file=DEFAULT_CREDENTIAL_FILE,
-                   globus_credential_file=DEFAULT_GLOBUS_CREDENTIAL_FILE,
-                   config_file=DEFAULT_CONFIG_FILE,
-                   requested_scope=None,
-                   force_scope_lookup=False,
-                   match_scope_tag="deriva-all"):
-    # load deriva credential set first
-    credentials = read_credential(credential_file or DEFAULT_CREDENTIAL_FILE, create_default=True)
-    creds = credentials.get(host, credentials.get(host.lower(), dict()))
-
-    # if present, load globus credentials and merge
-    globus_credentials = read_credential(globus_credential_file or DEFAULT_GLOBUS_CREDENTIAL_FILE, create_default=True)
-    if globus_credentials:
-        scopes = get_oauth_scopes_for_host(host,
-                                           config_file=config_file,
-                                           force_refresh=force_scope_lookup,
-                                           warn_on_discovery_failure=True if not creds else False)
-        for resource, g_creds in globus_credentials.items():
-            # 1. look for the explicitly requested scope in the token store, if specified
-            if requested_scope is not None and g_creds["scope"] == requested_scope:
-                creds["bearer-token"] = g_creds["access_token"]
-                break
-
-            # 2. try to determine the scope to use based on host-to-scope(s) mappings
-            if scopes:
-                for k, v in scopes.items():
-                    if v == g_creds["scope"]:
-                        if match_scope_tag is not None and match_scope_tag != k:
-                            continue
-                        creds["bearer-token"] = g_creds["access_token"]
-                        break
-                if creds.get("bearer-token"):
-                    break
-            else:
-                # 3. if we did not find any host-to-scope(s) mappings in the config file, just fall back and
-                # try to find a token by matching the hostname to the resource server name
-                if host.lower() == resource.lower():
-                    creds["bearer-token"] = g_creds["access_token"]
-                    break
-
-    return creds or None
-
-
 def get_oauth_scopes_for_host(host,
                               config_file=DEFAULT_CONFIG_FILE,
                               force_refresh=False,
@@ -301,6 +275,8 @@ def get_oauth_scopes_for_host(host,
     result = dict()
     upr = urlparse(host)
     if upr.scheme and upr.netloc:
+        if upr.scheme not in ("http", "https"):
+            return result
         url = urljoin(host, "/authn/discovery")
         host = upr.hostname
     else:
@@ -376,9 +352,6 @@ def load_cookies_from_file(cookie_file=None):
 
 
 def resource_path(relative_path, default=os.path.abspath(".")):
-    # required to find bundled data at runtime in Pyinstaller single-file exe mode
-    if getattr(sys, 'frozen', False):
-        return os.path.join(getattr(sys, '_MEIPASS', '.'), relative_path)
     if default is None:
         return relative_path
     return os.path.join(default, relative_path)
